package com.smarthomies.realtimetalk.views.activities;

import android.content.Intent;
import android.databinding.DataBindingUtil;
import android.os.Bundle;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.support.design.widget.NavigationView;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.widget.Toolbar;
import android.view.Menu;
import android.view.MenuItem;

import com.smarthomies.realtimetalk.R;
import com.smarthomies.realtimetalk.RTTActivity;
import com.smarthomies.realtimetalk.databinding.ActivityMainBinding;
import com.smarthomies.realtimetalk.databinding.AppBarMainBinding;
import com.smarthomies.realtimetalk.databinding.NavHeaderMainBinding;
import com.smarthomies.realtimetalk.models.db.User;
import com.smarthomies.realtimetalk.viewmodels.UserViewModel;
import com.smarthomies.realtimetalk.views.adapters.UsersAdapter;
import com.smarthomies.realtimetalk.views.fragments.MainViewModelHolder;
import com.smarthomies.realtimetalk.views.fragments.registration.RegistrationViewModelHolder;

import java.util.ArrayList;

public class MainActivity extends RTTActivity
        implements NavigationView.OnNavigationItemSelectedListener {

    private MainViewModelHolder viewModelHolder;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        // Add retained to fragment manager
        if(getSupportFragmentManager().findFragmentByTag(MainViewModelHolder.class.getName()) == null) {
            viewModelHolder = new MainViewModelHolder();

            getSupportFragmentManager()
                    .beginTransaction()
                    .add(viewModelHolder, MainViewModelHolder.class.getName())
                    .commit();
        }
        else {
            viewModelHolder = (MainViewModelHolder)getSupportFragmentManager().findFragmentByTag(MainViewModelHolder.class.getName());
        }

        ActivityMainBinding binding = DataBindingUtil.setContentView(this, R.layout.activity_main);
        AppBarMainBinding appBarMainBinding = binding.appBarMain;
        User user = new User();
        user.setFirstName("Ensar");
        user.setLastName("Sarajcic");
        user.setEmail("es.ensar@gmail.com");
        user.setImageUrl("https://avatars3.githubusercontent.com/u/2764831?v=3&s=460");
        viewModelHolder.getMainViewModel().setUser(user);
        binding.setViewModel(viewModelHolder.getMainViewModel());
        appBarMainBinding.setViewModel(viewModelHolder.getMainViewModel());

        RecyclerView recyclerView = (RecyclerView) findViewById(R.id.rvUsersList);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));

        UsersAdapter usersAdapter = new UsersAdapter(UsersAdapter.ViewType.LIST);
        ArrayList<User> users = new ArrayList<User>();
        users.add(user);
        usersAdapter.setUsers(users);

        recyclerView.setAdapter(usersAdapter);

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);


        setSupportActionBar(toolbar);

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(
                this, drawer, toolbar, R.string.navigation_drawer_open, R.string.navigation_drawer_close);
        drawer.setDrawerListener(toggle);
        toggle.syncState();

        binding.navView.setNavigationItemSelectedListener(this);
    }

    @Override
    public void onBackPressed() {
        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        if (drawer.isDrawerOpen(GravityCompat.START)) {
            drawer.closeDrawer(GravityCompat.START);
        } else {
            super.onBackPressed();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @SuppressWarnings("StatementWithEmptyBody")
    @Override
    public boolean onNavigationItemSelected(MenuItem item) {
        // Handle navigation view item clicks here.
        int id = item.getItemId();

        if (id == R.id.nav_logout) {
            // Handle the camera action
            startActivity(new Intent(this, LoginActivity.class));
            finish();
        }

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        drawer.closeDrawer(GravityCompat.START);
        return true;
    }

    public MainViewModelHolder getViewModelHolder() {
        return viewModelHolder;
    }

}
